@@ -1,4 +1,4 @@
-# Copyright 2010-2019 The pygit2 contributors
+# Copyright 2010-2021 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -35,7 +35,7 @@ from os import getenv
 #
 # The version number of pygit2
 #
-__version__ = '1.0.1'
+__version__ = '1.7.2'
 
 
 #
@@ -54,9 +54,21 @@ def _get_libgit2_path():
 
 
 def get_libgit2_paths():
-    libgit2_path = _get_libgit2_path()
+    # Base path
+    path = _get_libgit2_path()
+
+    # Library dirs
+    libgit2_lib = getenv('LIBGIT2_LIB')
+    if libgit2_lib is None:
+        libgit2_lib = [os.path.join(path, 'lib'), os.path.join(path, 'lib64')]
+    else:
+        libgit2_lib = [libgit2_lib]
+
     return (
-        os.path.join(libgit2_path, 'bin'),
-        os.path.join(libgit2_path, 'include'),
-        getenv('LIBGIT2_LIB', os.path.join(libgit2_path, 'lib')),
+        os.path.join(path, 'bin'),
+        {
+            'libraries': ['git2'],
+            'include_dirs': [os.path.join(path, 'include')],
+            'library_dirs': libgit2_lib,
+        }
     )
